@@ -1253,74 +1253,6 @@ INT64_T chirp_client_lchown(struct chirp_client * c, char const *path, INT64_T u
 	return simple_command(c, stoptime, "lchown %s %lld %lld\n", safepath, uid, gid);
 }
 
-INT64_T chirp_client_job_begin(struct chirp_client * c, const char *cwd, const char *infile, const char *outfile, const char *errfile, const char *cmdline, time_t stoptime)
-{
-	char safeinfile[CHIRP_PATH_MAX];
-	char safeoutfile[CHIRP_PATH_MAX];
-	char safeerrfile[CHIRP_PATH_MAX];
-
-	url_encode(infile, safeinfile, sizeof(safeinfile));
-	url_encode(outfile, safeoutfile, sizeof(safeoutfile));
-	url_encode(errfile, safeerrfile, sizeof(safeerrfile));
-
-	return simple_command(c, stoptime, "job_begin %s %s %s %s %s\n", cwd, safeinfile, safeoutfile, safeerrfile, cmdline);
-}
-
-INT64_T chirp_client_job_commit(struct chirp_client * c, INT64_T jobid, time_t stoptime)
-{
-	return simple_command(c, stoptime, "job_commit %lld\n", jobid);
-}
-
-INT64_T chirp_client_job_kill(struct chirp_client * c, INT64_T jobid, time_t stoptime)
-{
-	return simple_command(c, stoptime, "job_kill %lld\n", jobid);
-}
-
-INT64_T chirp_client_job_remove(struct chirp_client * c, INT64_T jobid, time_t stoptime)
-{
-	return simple_command(c, stoptime, "job_remove %lld\n", jobid);
-}
-
-INT64_T chirp_client_job_wait(struct chirp_client * c, INT64_T jobid, struct chirp_job_state * state, int wait_time, time_t stoptime)
-{
-	char line[CHIRP_LINE_MAX];
-	INT64_T result = simple_command(c, stoptime, "job_wait %lld %lu\n", jobid, wait_time);
-	if(result >= 0) {
-		if(link_readline(c->link, line, sizeof(line), stoptime)) {
-			if(sscanf(line, "%lld %s %s %d %d %lu %lu %lu %d", &state->jobid, state->command, state->owner, (int *) &state->state, &state->exit_code, &state->submit_time, &state->start_time, &state->stop_time, &state->pid)
-				) {
-				return 0;
-			} else {
-				errno = ECONNRESET;
-				return -1;
-			}
-		}
-	}
-	return result;
-}
-
-INT64_T chirp_client_job_list(struct chirp_client * c, chirp_joblist_t callback, void *arg, time_t stoptime)
-{
-	char line[CHIRP_LINE_MAX];
-	INT64_T result = simple_command(c, stoptime, "job_list\n");
-	if(result >= 0) {
-		while(link_readline(c->link, line, sizeof(line), stoptime)) {
-			struct chirp_job_state state;
-			if(!line[0])
-				return 0;
-			if(sscanf(line, "%lld %s %s %d %d %lu %lu %lu %d", &state.jobid, state.command, state.owner, (int *) &state.state, &state.exit_code, &state.submit_time, &state.start_time, &state.stop_time, &state.pid)
-				) {
-				callback(&state, arg);
-				continue;
-			} else {
-				errno = ECONNRESET;
-				return -1;
-			}
-		}
-	}
-	return result;
-}
-
 INT64_T chirp_client_md5(struct chirp_client * c, const char *path, unsigned char digest[16], time_t stoptime)
 {
 	INT64_T result;
@@ -1345,6 +1277,13 @@ INT64_T chirp_client_md5(struct chirp_client * c, const char *path, unsigned cha
 	return result;
 }
 
+INT64_T chirp_client_setrep(struct chirp_client * c, char const *path, int nreps, time_t stoptime)
+{
+	char safepath[CHIRP_LINE_MAX];
+	url_encode(path, safepath, sizeof(safepath));
+	return simple_command(c, stoptime, "setrep %s %d\n", safepath, nreps);
+}
+
 INT64_T chirp_client_remote_debug(struct chirp_client * c, const char *flag, time_t stoptime)
 {
 	if(flag == NULL) flag = "*";
@@ -1412,71 +1351,6 @@ INT64_T chirp_client_lsalloc(struct chirp_client * c, char const *path, char *al
 	return result;
 }
 
-INT64_T chirp_client_group_create(struct chirp_client * c, char *group, time_t stoptime)
-{
-	return simple_command(c, stoptime, "group_create %s\n", group);
-}
-
-INT64_T chirp_client_group_add(struct chirp_client * c, char *group, char *user, time_t stoptime)
-{
-	return simple_command(c, stoptime, "group_add %s %s\n", group, user);
-}
-
-INT64_T chirp_client_group_remove(struct chirp_client * c, char *group, char *user, time_t stoptime)
-{
-	return simple_command(c, stoptime, "group_remove %s %s\n", group, user);
-}
-
-INT64_T chirp_client_group_lookup(struct chirp_client * c, const char *group, const char *user, time_t stoptime)
-{
-	return simple_command(c, stoptime, "group_lookup %s %s\n", group, user);
-}
-
-INT64_T chirp_client_group_list(struct chirp_client * c, const char *group, chirp_dir_t callback, void *arg, time_t stoptime)
-{
-	char line[CHIRP_LINE_MAX];
-
-	INT64_T result = simple_command(c, stoptime, "group_list %s\n", group);
-	if(result < 0)
-		return result;
-
-	while(link_readline(c->link, line, sizeof(line), stoptime)) {
-		if(line[0]) {
-			callback(line, arg);
-		} else {
-			return 0;
-			break;
-		}
-	}
-
-	return -1;
-}
-
-INT64_T chirp_client_group_cache_update(struct chirp_client * c, const char *group, time_t mod_time, time_t stoptime)
-{
-	return simple_command(c, stoptime, "group_cache_update %s %ld\n", group, mod_time);
-}
-
-INT64_T chirp_client_group_policy_set(struct chirp_client * c, char *group, unsigned long int file_duration, unsigned long int dec_duration, time_t stoptime)
-{
-	return simple_command(c, stoptime, "group_policy_set %s %ld %ld\n", group, file_duration, dec_duration);
-}
-
-INT64_T chirp_client_group_policy_get(struct chirp_client * c, const char *group, int *policy, int *file_duration, int *dec_duration, time_t stoptime)
-{
-	char line[CHIRP_LINE_MAX];
-	INT64_T result;
-
-	result = link_putfstring(c->link, "group_policy_get %s\n", stoptime, group);
-	debug(D_CHIRP, "= %lld", result);
-
-	link_readline(c->link, line, CHIRP_LINE_MAX, stoptime);
-	result = get_result(c, stoptime);
-	sscanf(line, "%d %d %d", policy, file_duration, dec_duration);
-
-	return result;
-}
-
 static INT64_T convert_result(INT64_T result)
 {
 	if(result >= 0) {
