@@ -13,6 +13,10 @@ This module written by James Fitzgerald, B.S. 2006.
 #define FUSE_USE_VERSION 27
 
 #include <fuse.h>
+
+#include <unistd.h>
+#include <dirent.h>
+#include <fcntl.h>
 #include <pthread.h>
 
 #include "chirp_global.h"
@@ -21,17 +25,16 @@ This module written by James Fitzgerald, B.S. 2006.
 
 #include "auth_all.h"
 #include "debug.h"
-#include "stringtools.h"
 #include "itable.h"
+#include "stringtools.h"
+#include "string_array.h"
+#include "xmalloc.h"
 
+#include <errno.h>
+#include <signal.h>
 #include <stdio.h>
 #include <stdlib.h>
 #include <string.h>
-#include <unistd.h>
-#include <fcntl.h>
-#include <dirent.h>
-#include <errno.h>
-#include <signal.h>
 
 static int chirp_fuse_timeout = 60;
 static int run_in_foreground = 0;
@@ -561,13 +564,15 @@ static void show_help(const char *cmd)
 {
 	printf("use: %s <mountpath>\n", cmd);
 	printf("where options are:\n");
-	printf(" -t <timeout> Timeout for network operations. (default is %ds)\n", chirp_fuse_timeout);
-	printf(" -b <bytes>   Block size for network I/O. (default is %ds)\n", (int) chirp_reli_blocksize_get());
 	printf(" -a <flag>    Require this authentication mode.\n");
+	printf(" -b <bytes>   Block size for network I/O. (default is %ds)\n", (int) chirp_reli_blocksize_get());
 	printf(" -d <flag>    Enable debugging for this subsystem.\n");
-	printf(" -o <file>    Send debugging output to this file.\n");
 	printf(" -D           Disable small file optimizations such as recursive delete.\n");
 	printf(" -f           Run in foreground for debugging.\n");
+	printf(" -i <files> Comma-delimited list of tickets to use for authentication.\n");
+	printf(" -m <options> Mount options passed to FUSE.\n");
+	printf(" -o <file>    Send debugging output to this file.\n");
+	printf(" -t <timeout> Timeout for network operations. (default is %ds)\n", chirp_fuse_timeout);
 	printf(" -v           Show program version.\n");
 	printf(" -h           This message.\n");
 }
@@ -576,10 +581,15 @@ int main(int argc, char *argv[])
 {
 	char c;
 	int did_explicit_auth = 0;
+	char *tickets = NULL;
+	struct fuse_args fa;
+	fa.argc = 0;
+	fa.argv = string_array_new();
+	fa.allocated = 1;
 
 	debug_config(argv[0]);
 
-	while((c = getopt(argc, argv, "d:Db:o:a:t:fhv")) != -1) {
+	while((c = getopt(argc, argv, "a:b:d:Dfhi:m:o:t:v")) != -1) {
 		switch (c) {
 		case 'd':
 			debug_flags_set(optarg);
@@ -590,6 +600,13 @@ int main(int argc, char *argv[])
 		case 'b':
 			chirp_reli_blocksize_set(atoi(optarg));
 			break;
+		case 'i':
+			tickets = xstrdup(optarg);
+			break;
+		case 'm':
+			fa.argc += 1;
+			fa.argv = string_array_append(fa.argv, optarg);
+			break;
 		case 'o':
 			debug_config_file(optarg);
 			break;
@@ -624,6 +641,14 @@ int main(int argc, char *argv[])
 
 	if(!did_explicit_auth)
 		auth_register_all();
+	if(tickets) {
+		auth_ticket_load(tickets);
+		free(tickets);
+	} else if(getenv(CHIRP_CLIENT_TICKETS)) {
+		auth_ticket_load(getenv(CHIRP_CLIENT_TICKETS));
+	} else {
+		auth_ticket_load(NULL);
+	}
 
 	file_table = itable_create(0);
 
@@ -631,13 +656,13 @@ int main(int argc, char *argv[])
 	signal(SIGINT, exit_handler);
 	signal(SIGTERM, exit_handler);
 
-	fuse_chan = fuse_mount(fuse_mountpoint, 0);
+	fuse_chan = fuse_mount(fuse_mountpoint, &fa);
 	if(!fuse_chan) {
 		fprintf(stderr, "chirp_fuse: couldn't access %s\n", fuse_mountpoint);
 		return 1;
 	}
 
-	fuse_instance = fuse_new(fuse_chan, 0, &chirp_fuse_operations, sizeof(chirp_fuse_operations), 0);
+	fuse_instance = fuse_new(fuse_chan, &fa, &chirp_fuse_operations, sizeof(chirp_fuse_operations), 0);
 	if(!fuse_instance) {
 		fuse_unmount(fuse_mountpoint, fuse_chan);
 		fprintf(stderr, "chirp_fuse: couldn't access %s\n", fuse_mountpoint);
@@ -661,6 +686,8 @@ int main(int argc, char *argv[])
 	fuse_unmount(fuse_mountpoint, fuse_chan);
 	fuse_destroy(fuse_instance);
 
+	free(fa.argv);
+
 	return 0;
 }
 
