@@ -18,6 +18,7 @@ See the file COPYING for details.
 #include "chirp_audit.h"
 #include "chirp_thirdput.h"
 
+#include "daemon.h"
 #include "macros.h"
 #include "debug.h"
 #include "link.h"
@@ -97,8 +98,9 @@ static int exit_if_parent_fails = 0;
 static const char *listen_on_interface = 0;
 static const char *chirp_root_url = ".";
 static const char *chirp_root_path = 0;
+static char *chirp_debug_file = NULL;
 
-char *chirp_transient_path = "./";	/* local file system stuff */
+char *chirp_transient_path = NULL;	/* local file system stuff */
 extern const char *chirp_ticket_path;
 const char *chirp_super_user = "";
 const char *chirp_group_base_url = 0;
@@ -368,6 +370,7 @@ int main(int argc, char *argv[])
 	char c;
 	int c_input;
 	time_t current;
+	int is_daemon = 0;
 
 	change_process_title_init(argv);
 	change_process_title("chirp_server");
@@ -379,7 +382,7 @@ int main(int argc, char *argv[])
 	/* Ensure that all files are created private by default. */
 	umask(0077);
 
-	while((c_input = getopt(argc, argv, "A:a:c:CEe:F:G:t:T:i:I:s:Sn:M:P:p:Q:r:Ro:O:d:vw:W:u:U:hXNL:f:y:x:z:Z:")) != (char)-1) {
+	while((c_input = getopt(argc, argv, "A:a:bc:CEe:F:G:t:T:i:I:s:Sn:M:P:p:Q:r:Ro:O:d:vw:W:u:U:hXNL:f:y:x:z:Z:")) != (char)-1) {
 		c = (char) c_input;
 		switch (c) {
 		case 'A':
@@ -389,6 +392,9 @@ int main(int argc, char *argv[])
 			auth_register_byname(optarg);
 			did_explicit_auth = 1;
 			break;
+		case 'b':
+			is_daemon = 1;
+			break;
 		case 'c':
 			auth_unix_challenge_dir(optarg);
 			break;
@@ -448,7 +454,8 @@ int main(int argc, char *argv[])
 			chirp_acl_force_readonly();
 			break;
 		case 'o':
-			debug_config_file(optarg);
+			free(chirp_debug_file);
+			chirp_debug_file = strdup(optarg);
 			break;
 		case 'O':
 			debug_config_file_size(string_metric_parse(optarg));
@@ -484,7 +491,8 @@ int main(int argc, char *argv[])
 			fprintf(stderr,"chirp_server: option -f is deprecated, use -r with a URL instead.");
 			break;
 		case 'y':
-			chirp_transient_path = optarg;
+			free(chirp_transient_path);
+			chirp_transient_path = strdup(optarg);
 			break;
 		case 'x':
 			fprintf(stderr,"chirp_server: option -x is deprecated, use -r with a URL instead.");
@@ -502,13 +510,27 @@ int main(int argc, char *argv[])
 			return 1;
 		}
 	}
+	if(is_daemon) daemonize(0); /* don't chdir to "/" */
+
+	/* Ensure that all files are created private by default (again because of daemonize). */
+	umask(0077);
+
+	/* open debug file now because daemonize closes all open fds */
+	debug_config_file(chirp_debug_file);
+
+	/* if chirp_transient_path is NULL, use CWD */
+	if(chirp_transient_path == NULL){
+		chirp_transient_path = realloc(chirp_transient_path, 8192);
+		if(getcwd(chirp_transient_path, 8192) == NULL){
+			fatal("could not get current working directory: %s", strerror(errno));
+		}
+	} else if(!create_dir(chirp_transient_path, S_IRWXU)) {
+		fatal("could not create transient data directory '%s': %s", chirp_transient_path, strerror(errno));
+	}
 
 	if(pipe(config_pipe)<0)
 		fatal("could not create internal pipe: %s",strerror(errno));
 
-	if(!create_dir(chirp_transient_path, 0711))
-		fatal("could not create transient data directory '%s'", chirp_transient_path);
-
 	if(dont_dump_core) {
 		struct rlimit rl;
 		rl.rlim_cur = rl.rlim_max = 0;
@@ -1427,7 +1449,7 @@ static void chirp_handler(struct link *l, const char *addr, const char *subject)
 		} else if(sscanf(line, "rmdir %s", path) == 1) {
 			if(!chirp_path_fix(path))
 				goto failure;
-			if(chirp_acl_check(path, subject, CHIRP_ACL_DELETE) || chirp_acl_check_dir(path, subject, CHIRP_ACL_DELETE)) {
+			if(chirp_acl_check_link(path, subject, CHIRP_ACL_DELETE) || chirp_acl_check_dir(path, subject, CHIRP_ACL_DELETE)) {
 				result = chirp_alloc_rmdir(path);
 			} else {
 				goto failure;
@@ -1435,7 +1457,7 @@ static void chirp_handler(struct link *l, const char *addr, const char *subject)
 		} else if(sscanf(line, "rmall %s", path) == 1) {
 			if(!chirp_path_fix(path))
 				goto failure;
-			if(chirp_acl_check(path, subject, CHIRP_ACL_DELETE) || chirp_acl_check_dir(path, subject, CHIRP_ACL_DELETE)) {
+			if(chirp_acl_check_link(path, subject, CHIRP_ACL_DELETE) || chirp_acl_check_dir(path, subject, CHIRP_ACL_DELETE)) {
 				result = chirp_alloc_rmall(path);
 			} else {
 				goto failure;
