@@ -18,6 +18,7 @@ See the file COPYING for details.
 #include "list.h"
 #include "xmalloc.h"
 #include "macros.h"
+#include "daemon.h"
 
 #include <stdlib.h>
 #include <stdio.h>
@@ -63,6 +64,10 @@ static INT64_T max_server_size = 0;
 
 /* Logfile for new updates. */
 static FILE *logfile = 0;
+static char *logfilename = 0;
+
+/* debug filename */
+static char *debug_filename = 0;
 
 /* Settings for the master catalog that we will report *to* */
 static int outgoing_alarm = 0;
@@ -417,52 +422,66 @@ int main(int argc, char *argv[])
 	struct link *link, *list_port = 0;
 	char ch;
 	time_t current;
+	int is_daemon = 0;
 
 	outgoing_host_list = list_create();
 
 	debug_config(argv[0]);
 
-	while((ch = getopt(argc, argv, "p:l:L:M:d:o:O:u:U:Shv")) != (char) -1) {
+	while((ch = getopt(argc, argv, "bp:l:L:M:d:o:O:u:U:Shv")) != (char) -1) {
 		switch (ch) {
-		case 'd':
-			debug_flags_set(optarg);
-			break;
-		case 'M':
-			max_server_size = string_metric_parse(optarg);
-			break;
-		case 'p':
-			port = atoi(optarg);
-			break;
-		case 'o':
-			debug_config_file(optarg);
-			break;
-		case 'O':
-			debug_config_file_size(string_metric_parse(optarg));
-			break;
-		case 'u':
-			list_push_head(outgoing_host_list, xstrdup(optarg));
-			break;
-		case 'U':
-			outgoing_timeout = string_time_parse(optarg);
-			break;
-		case 'l':
-			lifetime = string_time_parse(optarg);
-			break;
-		case 'L':
-			logfile = fopen(optarg,"a");
-			if(!logfile) fatal("couldn't open %s: %s\n",optarg,strerror(errno));
-			break;
-		case 'S':
-			fork_mode = 0;
-			break;
-		case 'v':
-			show_version(argv[0]);
-			return 0;
-		case 'h':
-		default:
-			show_help(argv[0]);
-			return 1;
-		}
+			case 'b':
+				is_daemon = 1;
+				break;
+			case 'd':
+				debug_flags_set(optarg);
+				break;
+			case 'M':
+				max_server_size = string_metric_parse(optarg);
+				break;
+			case 'p':
+				port = atoi(optarg);
+				break;
+			case 'o':
+				free(debug_filename);
+				debug_filename = strdup(optarg);
+				break;
+			case 'O':
+				debug_config_file_size(string_metric_parse(optarg));
+				break;
+			case 'u':
+				list_push_head(outgoing_host_list, xstrdup(optarg));
+				break;
+			case 'U':
+				outgoing_timeout = string_time_parse(optarg);
+				break;
+			case 'l':
+				lifetime = string_time_parse(optarg);
+				break;
+			case 'L':
+				free(logfilename);
+				logfilename = strdup(optarg);
+				break;
+			case 'S':
+				fork_mode = 0;
+				break;
+			case 'v':
+				show_version(argv[0]);
+				return 0;
+			case 'h':
+			default:
+				show_help(argv[0]);
+				return 1;
+			}
+	}
+
+	if (is_daemon) daemonize(0);
+
+	debug_config_file(debug_filename);
+
+	if(logfilename) {
+		logfile = fopen(logfilename,"a");
+		if(!logfile) fatal("couldn't open %s: %s\n",optarg,strerror(errno));
 	}
 
 	current = time(0);
