@@ -89,10 +89,10 @@ struct work_queue_task {
 	int result;			/**< The result of the task (successful, failed return_status, missing input file, missing output file). */
 	char *host;			/**< The name of the host on which it ran. */
 	timestamp_t submit_time;	/**< The time the task was submitted. */
-	timestamp_t start_time;		/**< The time at which the task began. */
-	timestamp_t finish_time;	/**< The time at which it completed. */
 	timestamp_t transfer_start_time;	/**< The time at which it started to transfer input files. */
-	timestamp_t computation_time;	/**< The time of executing the command. */
+	timestamp_t start_time;		/**< The time representing the start of the task. Recorded as the timestamp immediately after all its input files were transferred. */
+	timestamp_t finish_time;	/**< The time representing the end of the task. Recorded as the timestamp immediately after all its output files were received. */
+	timestamp_t computation_time;	/**< Elapsed time between start_time and the beginning of the transfer of output files. */
 	INT64_T total_bytes_transferred;/**< Number of bytes transferred since task has last started transferring input data. */
 	timestamp_t total_transfer_time;    /**< Time comsumed in microseconds for transferring total_bytes_transferred. */
 };
@@ -242,6 +242,12 @@ int work_queue_empty(struct work_queue *q);
 */
 int work_queue_port(struct work_queue *q);
 
+/** Get the project name of the queue.
+@param q The work queue of interest.
+@return The project name of the queue.
+*/
+const char *work_queue_name(struct work_queue *q);
+
 /** Get queue statistics.
 @param q The queue to query.
 @param s A pointer to a buffer that will be filed with statistics.
