@@ -41,6 +41,7 @@ See the file COPYING for details.
 #include <sys/stat.h>
 #include <sys/mman.h>
 #include <sys/signal.h>
+#include <sys/utsname.h>
 
 
 // Maximum time to wait before aborting if there is no connection to the master.
@@ -367,7 +368,7 @@ static void show_version(const char *cmd)
 
 static void show_help(const char *cmd)
 {
-	printf("Use: %s <masterhost> <port>\n", cmd);
+	printf("Use: %s [options] <masterhost> <port>\n", cmd);
 	printf("where options are:\n");
 	printf(" -a             Enable auto mode. In this mode the worker would ask a catalog server for available masters.\n");
 	printf(" -C <catalog>   Set catalog server to <catalog>. Format: HOSTNAME:PORT \n");
@@ -397,6 +398,7 @@ int main(int argc, char *argv[])
 	int ncpus;
 	char c;
 	char hostname[DOMAIN_NAME_MAX];
+	struct utsname uname_data;
 	int w;
 	char preferred_master_names[WORK_QUEUE_LINE_MAX];
 	char deletecmd[WORK_QUEUE_LINE_MAX];
@@ -517,6 +519,7 @@ int main(int argc, char *argv[])
         }	
 
 	domain_name_cache_guess(hostname);
+	uname(&uname_data);
 
 	time_t idle_stoptime = time(0) + idle_timeout;
 	time_t switch_master_time = time(0) + master_timeout;
@@ -559,11 +562,10 @@ int main(int argc, char *argv[])
 
 			link_tune(master, LINK_TUNE_INTERACTIVE);
 
-
 			if(exclusive_worker) {
-				link_putfstring(master, "ready %s %d %llu %llu %llu %llu \"%s\"\n", time(0) + active_timeout, hostname, ncpus, memory_avail, memory_total, disk_avail, disk_total, preferred_master_names);
+				link_putfstring(master, "ready %s %d %llu %llu %llu %llu \"%s\" %s %s\n", time(0) + active_timeout, hostname, ncpus, memory_avail, memory_total, disk_avail, disk_total, preferred_master_names, uname_data.sysname, uname_data.machine);
 			} else {
-				link_putfstring(master, "ready %s %d %llu %llu %llu %llu\n", time(0) + active_timeout, hostname, ncpus, memory_avail, memory_total, disk_avail, disk_total);
+				link_putfstring(master, "ready %s %d %llu %llu %llu %llu %s %s\n", time(0) + active_timeout, hostname, ncpus, memory_avail, memory_total, disk_avail, disk_total, uname_data.sysname, uname_data.machine);
 			}
 		}
 
